pub enum FileHeaderInfo {
NONE,
IGNORE,
USE,
}Expand description
Describes the first line of input.
Valid Values: USE | IGNORE | NONE.
Default: IGNORE
Variants
NONE
First line is not a header.
IGNORE
First line is a header, but you can’t use the header values to indicate the column in an expression.
You can use column position (such as _1, _2, …) to indicate the column (SELECT s._1 FROM OBJECT s).
USE
First line is a header, and you can use the header value to identify a column in an expression (SELECT "name" FROM OBJECT).